
# workstation

**This module is under active development and should not be considered production-ready at this time.**

#### Table of Contents

1. [Description](#description)
2. [Setup - The basics of getting started with workstation](#setup)
    * [What workstation affects](#what-workstation-affects)
    * [Setup requirements](#setup-requirements)
    * [Beginning with workstation](#beginning-with-workstation)
3. [Usage - Configuration options and additional functionality](#usage)
4. [Limitations - OS compatibility, etc.](#limitations)
5. [Development - Guide for contributing to the module](#development)

## Description

The workstation module manages tools and config for developer workstations, allowing developers to define, share, and combine workstation configurations in Hiera yaml.

This module is designed to provide a simple way to bootstrap a workstation with developer config. No prior experience with Puppet should be needed to use this module, only a working understanding of YAML. The workstation module is intended to be used via a `puppet apply` one-liner. However, this module can also be used in a master-agent setup, given an appropriate Hiera hierachy and hieradata in the control repo.

Currently this module only supports macOS, but Linux support will be added soon.

## Setup

### What workstation affects

This module manages settings for developer workstations. Initially it is focused on ensuring package installation, tool version installation, and dotfile configuration.

Current features:

* macOS Command Line Tools installation
* macOS package installation via `brew`, with full tap/cask support
* macOS tool version management via `asdf` (should also support Linux, currently untested)
* Basic macOS and Linux primary user shell configuration
* Basic macOS and Linux primary user dotfile management

### Setup Requirements

Puppet installed locally via `puppet-agent` [package](http://downloads.puppet.com/mac/) or `puppet` gem.

### Beginning with workstation

1) Ensure Puppet is installed. If you don't already have the Puppet Agent package installed, the easiest way to get Puppet is `sudo gem install puppet --no-ri --no-doc`.

2) Install this module locally, as root: `sudo puppet module install call-workstation`

3) Run `puppet apply` by copy-pasting one of the example one-liners below, depending on your shell. This will apply the configuration to the current user. Without additional hieradata, only the most basic user configuration will be applied (user shell, default packages).

Bash:

    sudo puppet apply -e "class {'workstation': user => $(whoami)}"

Zsh:

    sudo puppet apply -e "class {'workstation': user => $(whoami), shell => 'zsh'}"

Fish:

    sudo puppet apply -e "class {'workstation': user => "(whoami)", shell => 'fish'}"

4) To supply your own config data, use the `--hiera_config` flag to point to your custom hiera.yaml. See the 'Usage' section for more details. For example, for bash shell the command will look something like:

    sudo puppet apply -e "class {'workstation': user => $(whoami)}" --hiera_config /path/to/workstation-hieradata/hiera.yaml

Be sure to replace `/path/to/workstation-hieradata` with the real path to your Hiera directory that contains a hiera.yaml config file.

## Usage

In order to take full advantage of this module, you'll want to create a repository with your custom configuration data. To get started quickly, you can fork and modify the example at [call/workstation-hieradata](https://github.com/call/workstation-hieradata).

Importantly, in the [call/workstation-hieradata](https://github.com/call/workstation-hieradata) example, `data/common.yaml` contains settings to perform deep merges on package lookups, combined with a glob (*) for the lookup path. This pattern allows you to provide multiple yaml files in a single directory, which may have some overlapping package configuration, while avoiding the problem of duplicate resource declaration in Puppet. You may find it useful to provide a yaml file per application, per team, or based on some other grouping that requires a specific set of config.

Hiera directory structure and lookup behavior is highly configurable. See the [Puppet docs on hiera.yaml](https://puppet.com/docs/puppet/6.1/hiera_config_yaml_5.html) to learn more.

## Limitations

This module currently only supports macOS. Support will be expanded to Linux workstations in the near future.

## Development

Fork, improve, and PR!
