# @summary Installs asdf plugins and specified package versions.
#
# @example Basic usage
#   $packages = {
#     'python' => ['3.6.7', '3.7.1'],
#     'ruby'   => ['2.4.5']
#   }
#
#   class { 'workstation::asdf::packages':
#     user     => 'myuser',
#     home     => '/home/myuser',
#     timeout  => 300,
#     packages => $packages,
#   }
#
# @see https://github.com/asdf-vm
#
# @param user
#   The name of the user account to install asdf under.
# @param home
#   The path to the home folder for the user.
# @param timeout
#   The time allowed for each asdf package installation, in seconds.
# @param packages
#   A hash of packages to manage. Hash keys are package names, hash values are arrays of version strings to install.
#
class workstation::asdf::packages (
  String[1] $user = $workstation::user,
  String[1] $home = $workstation::home,
  Integer $timeout = $workstation::asdf::timeout,
  Optional[Hash[String[1], Array[String[1]]]] $packages = $workstation::asdf::packages,
) {

  if $packages {
    $packages.each |String $pkg, Array[String[1]] $versions| {
      exec { "${home}/.asdf/bin/asdf plugin-add ${pkg}":
        user        => $user,
        environment => ["HOME=${home}"],
        unless      => "${home}/.asdf/bin/asdf plugin-update ${pkg}",
      }

      $versions.each |String $v|{
        exec { "${home}/.asdf/bin/asdf install ${pkg} ${v}":
          user        => $user,
          environment => ["HOME=${home}"],
          timeout     => $timeout,
          unless      => "${home}/.asdf/bin/asdf list ${pkg} | awk \'{\$1=\$1};1\' | grep -Fx ${v}",
          require     => Exec["${home}/.asdf/bin/asdf plugin-add ${pkg}"],
        }
      }
    }
  } else {
    notice('No asdf installs provided.')
  }

}
