# @summary Installs Homebrew package manager for macOS. Wraps thekevjames-homebrew module.
#
# @example Basic usage
#   class { 'workstation::mac::homebrew::manage':
#     github_token => '123456789asdfghjk3245678sdfghjk',
#     user         => 'myuser',
#   }
#
# @see https://forge.puppet.com/thekevjames/homebrew
#
# @param github_token
#   A GitHub personal access token that allows higher GitHub rate limits for Homebrew operations, if needed.
# @param user
#   The username of the primary homebrew user. Should be set to the primary user of the workstation.
# @param group
#   The user group to use for homebrew. Defaults to 'admin'.
# @param multiuser
#   Whether to configure multi-user setup for homebrew.
#
class workstation::mac::homebrew::manage (
  Optional[String[1]] $github_token = $workstation::github_token,
  String[1] $user = $workstation::user,
  String[1] $group = 'admin',
  Boolean $multiuser = false,
) {

  # This should be submitted as a PR to puppet-homebrew
  $chown_dirs = [
    '/usr/local/sbin',
    '/usr/local/share/man/man1',
    '/usr/local/share/man/man2',
    '/usr/local/share/man/man3',
    '/usr/local/share/man/man4',
    '/usr/local/share/man/man5',
    '/usr/local/share/man/man6',
    '/usr/local/share/man/man7',
    '/usr/local/share/man/man8',
    '/usr/local/share/man/man9',
    '/usr/local/share/man/mann',
  ]

  file { $chown_dirs:
    ensure => directory,
    owner  => $user,
  }

  class { 'homebrew':
    user         => $user,
    github_token => $github_token,
    group        => $group,
    multiuser    => $multiuser,
  }

}
